# -*- coding: utf-8 -*-
from django.db import models
from polymorphic import PolymorphicModel
from coin.offers.models import OfferSubscription

class Configuration(PolymorphicModel):

    offersubscription = models.OneToOneField(OfferSubscription, blank=True, null=True, related_name='configuration')

    @staticmethod
    def get_configurations_choices_list():
        """
        Génère automatiquement la liste de choix possibles en fonction des classes enfants de Configuration
        """
        return tuple((x().__class__.__name__,x()._meta.verbose_name) for x in Configuration.__subclasses__())
    
    def model_name(self):
        return self.__class__.__name__

    def configuration_type_name(self):
        return self._meta.verbose_name

    def get_absolute_url(self):
        from django.core.urlresolvers import reverse
        return reverse('%s:details' % self.get_url_namespace(), args=[str(self.id)])

    def get_url_namespace(self):
        if self.url_namespace:
            return self.url_namespace
        else:
            return self.model_name().lower()